/* Copyright 2023 Red Hat, Inc. (www.redhat.com)
 *
 * This library is free software: you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 * or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library. If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include "evolution-data-server-config.h"

#include <glib.h>

#include "e-dbus-prefix.h"

static char *
read_prefix (gpointer data)
{
	char *contents;

	if (g_file_get_contents (E_DATA_SERVER_SYSCONFDIR "/evolution-data-server/dbus-prefix",
				 &contents, NULL, NULL)) {
		g_strstrip (contents);
		return contents;
	} else {
		return NULL;
	}
}

const char *
e_dbus_prefix (const char *base)
{
	static GOnce read_prefix_once = G_ONCE_INIT;
	const char *prefix;

	g_once (&read_prefix_once, (GThreadFunc)read_prefix, NULL);
	prefix = read_prefix_once.retval;

	if (prefix) {
		char *prefixed = g_strconcat (prefix, ".", base, NULL);
		const char *result = g_intern_string (prefixed);
		g_free (prefixed);

		return result;
	} else {
		return base;
	}
}
